@@ -427,15 +427,20 @@ struct Daemon
     unsigned int current_kids;
 
     Daemon() {
-        struct passwd *pw = getpwnam("icecc");
-        if (pw) {
-            user_uid = pw->pw_uid;
-            user_gid = pw->pw_gid;
-            warn_icecc_user = false;
+        if ( getuid() == 0 ) {
+            struct passwd *pw = getpwnam("icecc");
+            if (pw) {
+                user_uid = pw->pw_uid;
+                user_gid = pw->pw_gid;
+                warn_icecc_user = false;
+            } else {
+                warn_icecc_user = true;
+                user_uid = 65534;
+                user_gid = 65533;
+            }
         } else {
-            warn_icecc_user = true;
-            user_uid = 65534;
-            user_gid = 65533;
+            user_uid = getuid();
+            user_gid = getgid();
         }
 
         envbasedir = "/tmp/icecc-envs";
@@ -1863,7 +1868,7 @@ int main( int argc, char ** argv )
     pidFile << dcc_master_pid << endl;
     pidFile.close();
 
-    if ( !cleanup_cache( d.envbasedir ) )
+    if ( !cleanup_cache( d.envbasedir, d.user_uid, d.user_gid ) )
         return 1;
 
     list<string> nl = get_netnames (200);
